@@ -21,7 +21,7 @@ def train_and_explainModel(model:str, tabular_data:Tabular, x_ai:list, indexList
     
     try:
       assert model in acceptedModels.keys()
-      import eval(acceptedModels.get(model))
+      exec('import ' + acceptedModels.get(model))
       modeler= eval(model + "( **modelSpecificArgs )") #Create model function from provided model name. This will not work if model is not part of sklearn library or is unsupervised.
     except Exception as e:
       print("Provided model name is incorrect or is not part of sklearn library. Only supervised learning models in sklearn are supported. Refer to models by their associated functions. For example, if you want to use support vector regression, pass in \"SVR\". \n Error message: " + str(e))
